==> invoice-client-4.1.5-20200228.110036-65-sources.jar: com/xforceplus/seller/invoice/client/model/NoticeBillMsg.java <==
package com.xforceplus.seller.invoice.client.model;

import java.util.List;

public class NoticeBillMsg {

    /**
     * 发票来源
     */
    private Integer invoiceOrigin;

    /**
     * 发票id
     */
    private Long invoiceId;

    /**
     * 批次号
     */
    private Long batchNo;

    /**
     * 明细金额
     */
    private List<DetailInfo> detailInfoList;

    /**
     * 发票号码
     */
    private String invoiceCode;

    /**
     * 发票代码
     */
    private String invoiceNo;

    public Long getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(Long batchNo) {
        this.batchNo = batchNo;
    }

    public List<DetailInfo> getDetailInfoList() {
        return detailInfoList;
    }

    public void setDetailInfoList(List<DetailInfo> detailInfoList) {
        this.detailInfoList = detailInfoList;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public Integer getInvoiceOrigin() {
        return invoiceOrigin;
    }

    public void setInvoiceOrigin(Integer invoiceOrigin) {
        this.invoiceOrigin = invoiceOrigin;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    @Override
    public String toString() {
        return "NoticeBillMsg{" +
                "batchNo=" + batchNo +
                ", detailInfoList=" + detailInfoList +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", invoiceNo='" + invoiceNo + '\'' +
                '}';
    }
}

==> invoice-client-4.1.42-20221026.091035-14-sources.jar: com/xforceplus/seller/invoice/client/model/NoticeBillMsg.java <==
package com.xforceplus.seller.invoice.client.model;

import java.util.List;

public class NoticeBillMsg {

    /**
     * 发票来源
     */
    private Integer invoiceOrigin;

    /**
     * 预制发票id
     */
    private Long preInvoiceId;

    /**
     * 发票id
     */
    private Long invoiceId;

    /**
     * 批次号
     */
    private Long batchNo;

    /**
     * 明细金额
     */
    private List<DetailInfo> detailInfoList;

    /**
     * 发票号码
     */
    private String invoiceCode;

    /**
     * 发票代码
     */
    private String invoiceNo;

    /**
     * 回写单据后需 1-下发协同 0-不下发协同, 默认下发
     */
    private Integer cooperationFlag = 1;

    public Long getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(Long batchNo) {
        this.batchNo = batchNo;
    }

    public List<DetailInfo> getDetailInfoList() {
        return detailInfoList;
    }

    public void setDetailInfoList(List<DetailInfo> detailInfoList) {
        this.detailInfoList = detailInfoList;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public Integer getInvoiceOrigin() {
        return invoiceOrigin;
    }

    public void setInvoiceOrigin(Integer invoiceOrigin) {
        this.invoiceOrigin = invoiceOrigin;
    }

    public Long getPreInvoiceId() {
        return preInvoiceId;
    }

    public void setPreInvoiceId(Long preInvoiceId) {
        this.preInvoiceId = preInvoiceId;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public Integer getCooperationFlag() {
        return cooperationFlag;
    }

    public void setCooperationFlag(Integer cooperationFlag) {
        this.cooperationFlag = cooperationFlag;
    }

    @Override
    public String toString() {
        return "NoticeBillMsg{" +
                "batchNo=" + batchNo +
                ", detailInfoList=" + detailInfoList +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", invoiceNo='" + invoiceNo + '\'' +
                ", cooperationFlag='" + cooperationFlag + '\'' +
                '}';
    }
}
